"""
This file is an installation script for CMFEmployment (Resume, JobOpenings).  It's meant to be
used as an External Method.  To use, add an external method to the
root of the CMF Site that you want CMF Resume and JobOpenings registered in with the
configuration:

 id: install_events
 title: Install Events *optional*
 module name: CMFEmployment.Install
 function name: install

Then go to the management screen for the newly added external method
and click the 'Try it' tab.  The install function will execute and give
information about the steps it took to register and install the
CMF Resumes into the CMF Site instance. 
"""

from Products.CMFCore.TypesTool import ContentFactoryMetadata
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.utils import getToolByName

from Products.CMFEmployment import Resume, resume_globals
from Products.CMFEmployment import JobPosting, jobposting_globals

from cStringIO import StringIO
import string

def install(self):
    " Register the CMFEmployment with portal_types and friends "

    out = StringIO()
    typestool = getToolByName(self, 'portal_types')
    skinstool = getToolByName(self, 'portal_skins')
    metadatatool = getToolByName(self, 'portal_metadata')
    
    # Borrowed from CMFDefault.Portal.PortalGenerator.setupTypes()
    # We loop through anything defined in the factory type information
    # and configure it in the types tool if it doesn't already exist

    # Install Resume 

#    for t in Resume.factory_type_information:
#        if t['id'] not in typestool.objectIds():
#            cfm = apply(ContentFactoryMetadata, (), t)
#            typestool._setObject(t['id'], cfm)
#            out.write('Registered Resume with the types tool\n')
#        else:
#            out.write('Object "%s" already existed in the types tool\n' % (
#                t['id']))
#
#    try:
#        metadatatool.addElementPolicy(element='Subject'
#           ,content_type='Resume'
#            ,is_required=0
#
#            ,supply_default=0
#            ,default_value=''
#            ,enforce_vocabulary=0
#            ,allowed_vocabulary=('Appointment', 'Convention', 'Meeting', 'Social Event', 'Work')
#            ,REQUEST=None
#            )
#        out.write('Resume added to Metadata element Policies\n')
#    except:
#        out.write('Resume Element policy already exists in MetadataTool\n')

    # Install Job Posting    

    for t in JobPosting.factory_type_information:
        if t['id'] not in typestool.objectIds():
            cfm = apply(ContentFactoryMetadata, (), t)
            typestool._setObject(t['id'], cfm)
            out.write('Registered Job Posting with the types tool\n')
        else:
            out.write('Object "%s" already existed in the types tool\n' % (
                t['id']))

    try:
        metadatatool.addElementPolicy(element='Subject'
            ,content_type='Job Posting'
            ,is_required=0
            ,supply_default=0
            ,default_value=''
            ,enforce_vocabulary=0
            ,allowed_vocabulary=('Appointment', 'Convention', 'Meeting', 'Social Event', 'Work')
            ,REQUEST=None )
        out.write('JobPosting added to Metadata element Policies\n')
    except:
            out.write('Job Posting ElementPolicy already exists in MetadataTool\n')
    
    # Setup the skins
    # This is borrowed from CMFDefault/scripts/addImagesToSkinPaths.pys
    if 'employment' not in skinstool.objectIds():
        # We need to add Filesystem Directory Views for any directories
        # in our skins/ directory.  These directories should already be
        # configured.
        addDirectoryViews(skinstool, 'skins', jobposting_globals)
        out.write("Added 'employment' directory view to portal_skins\n")

    # Now we need to go through the skin configurations and insert
    # 'employment' into the configurations.  Preferably, this should be
    # right before where 'content' is placed.  Otherwise, we append
    # it to the end.
    skins = skinstool.getSkinSelections()
    for skin in skins:
        path = skinstool.getSkinPath(skin)
        path = map(string.strip, string.split(path,','))
        if 'employment' not in path:
            try: path.insert(path.index('content'), 'employment')
            except ValueError:
                path.append('employment')
                
            path = string.join(path, ', ')
            # addSkinSelection will replace exissting skins as well.
            skinstool.addSkinSelection(skin, path)
            out.write("Added 'employment' to %s skin\n" % skin)
        else:
            out.write("Skipping %s skin, 'employment' is already set up\n" % (
                skin))

    #Final Stage: Init Products inside CMF 

    from whrandom import randint
    request=self.REQUEST

    login='PUBLIC' #account name
    passwd=randint(10000,30000)

    request.set('username', login) 
    request.set('email', 'webmaster@domain.com')

    getToolByName(self, 'portal_registration').addMember( login, str(passwd), properties=request)

    out.write ('successfully created, ' + login + '\n')

    #if you have the publicSubmitURLForm dtmlmethod in this directory it changes the proxy roles
    if hasattr(skinstool.employment, 'submitPublicJobPosting'):
        getattr(skinstool.employment, 'submitPublicJobPosting').manage_doCustomize('custom')
        try:
            getattr(skinstool.custom, 'submitPublicJobPosting').manage_proxy(['Member', 'Owner'])
        except:
            raise Exception, 'the account you are using to install CMFEmployment does not have the Member and Owner roles\n' + \
                             'You need to create an account ->' + str(self.REQUEST.AUTHENTICATED_USER) +'<- in the acl_users folder inside the portal instance.\n' 

    #allow anonymous users to 'Add portal content'
    root=getToolByName(self, 'portal_url').getPortalObject()
    root.manage_permission('Add portal content', roles=['Anonymous','Manager', 'Member'], acquire=1, REQUEST=request)

    #allow 'Anonymous to Request review' in the new Members.login folder
    mFolder = getattr(root.Members, login)
    mFolder.manage_permission('Request review', roles=['Anonymous'], acquire=1, REQUEST=request)

    mFolder.manage_addFolder('JobPostings','JobPostings')

    out.write('successfully assigned properties to submitPublicJobPosting Script(Python) and set _Request review_ on /Members/' + login + 'folder\n')

    return out.getvalue()

