import os, urllib
from DateTime import DateTime
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore.WorkflowCore import WorkflowAction, afterCreate

# Import permission names
from Products.CMFCore import CMFCorePermissions
import EmploymentPermissions

# Factory type information -- makes Events objects play nicely
# with the Types Tool (portal_types)
factory_type_information = (
    {'id': 'Resume',
     'content_icon': 'co_resume.gif',
     'meta_type': 'CMF Resume',
     'description': ('Events are objects for use in Calendar topical '
                     'queries on the catalog.'),
     'product': 'CMFEmployment',
     'factory': 'addResume',
     'immediate_view': 'resume_edit_form',
     'actions': ({'id': 'view',
                  'name': 'View',
                  'action': 'resume_view',
                  'permissions': (CMFCorePermissions.View,)},
                 {'id': 'edit',
                  'name': 'Edit',
                  'action': 'resume_edit_form',
                  'permissions': (EmploymentPermissions.modifyContent,)},
                 ),                     # End Actions
     },
    )

def addResume(self
             , id
             , title=''
             , description=''
             , effective_date = DateTime() 
             , expiration_date = DateTime() 
             , location=''
             , position_type=''
             , career_level=''
             , contact_name=''
             , contact_email=''
             , contact_phone=''
             , homepage_url=''
             , REQUEST=None):
    """
    Create an empty event.
    """
    resume = Resume(id
                  , title
                  , description
                  , employment_categories
                  , effective_date
                  , expiration_date
                  , location
                  , position_type
                  , career_level
                  , contact_name
                  , contact_email
                  , contact_phone
                  , homepage_url
                 )
    self._setObject(id, resume)
    afterCreate(self.this()._getOb(id))

def _dateStrings( when ):

    strings = {}

    if when is not None:
        strings[ 'year' ]   = str( when.year() )
        strings[ 'month' ]  = str( when.month() )
        strings[ 'day' ]    = str( when.day() )
    else:
        strings[ 'year' ]   = ''
        strings[ 'month' ]  = ''
        strings[ 'day' ]    = ''

    return strings

class Resume(PortalContent, DefaultDublinCoreImpl):
    """
    Resumes are objects for the Employment topical query.
    """
    meta_type='CMF Resume'

    # Declarative security
    security = ClassSecurityInfo()
    security.declareObjectProtected(CMFCorePermissions.View)
    
    def __init__(self
                 , id
                 , title=''
                 , description=''
                 , employment_categories=''
                 , effective_date = DateTime() 
                 , expiration_date = DateTime() 
                 , location=''
                 , position_type=''
                 , career_level=''
                 , contact_name=''
                 , contact_email=''
                 , contact_phone=''
                 , homepage_url=''
                ):
        DefaultDublinCoreImpl.__init__(self)
        self.id=id
        self.setTitle(title)
        self.setDescription(description)
        self.setSubject(employment_categories)
        self.setEffectiveDate(effective_date)
        self.setExpirationDate(expiration_date)
        self.location=location
        self.position_type=position_type
        self.career_level=career_level
        self.contact_name=contact_name
        self.contact_email=contact_email
        self.contact_phone=contact_phone
        self.homepage_url=homepage_url
    
    security.declarePublic('getExpirationStrings')
    def getExpirationStrings(self):
        """
        """
        return _dateStrings(self.expiration_date)

    security.declarePublic('getEffectiveStrings')
    def getEffectiveStrings(self):
        """
        """
        return _dateStrings(self.effective_date)

    security.declareProtected(EmploymentPermissions.modifyContent, 'edit')
    def edit(self
             , title=None
             , description=None
             , employmentCategories=None
             , effectiveDay=None
             , effectiveMo=None
             , effectiveYear=None
             , expirationDay=None
             , expirationMo=None
             , expirationYear=None
             , start_time=None
             , startAMPM=None
             , stop_time=None
             , stopAMPM=None
             , location=None
             , position_type=None
             , career_level=None
             , contact_name=None
             , contact_email=None
             , contact_phone=None
             , homepage_url=None
            ):
        """\
        """
        if title is not None: 
            self.setTitle(title)
        if description is not None:
            self.setDescription(description)
        if eventType is not None:
            self.setSubject(eventType)
        efdate = '%s/%s/%s %s %s' % (effectiveDay
                                 , effectiveMo
                                 , effectiveYear
                                 , start_time
                                 , startAMPM
                                 )

        exdate = '%s/%s/%s %s %s' % (expirationDay
                                 , expirationMo
                                 , expirationYear
                                 , stop_time
                                 , stopAMPM
                                 )
 
        self.setEffectiveDate(DateTime(efdate))
        self.setExpirationDate(DateTime(exdate))
        if location is not None:
            self.location = location
        if contact_name is not None:
            self.contact_name = contact_name
        if contact_email is not None:
            self.contact_email = contact_email
        if contact_phone is not None:
            self.contact_phone = contact_phone
        if homepage_url is not None:
            self.homepage_url = homepage_url
        if position_type is not None:
            self.position_type = position_type
        if career_level is not None:
            self.career_level = career_level
        self.reindexObject()
    edit = WorkflowAction(edit) 
    
    security.declarePublic('buildTimes')
    def buildTimes(self):
        result = []
        for hour in range (1, 13):
            for min in (00, 30):
                result.append('%02d:%02d' % (hour, min))
        return result
    
    security.declarePublic('buildDays')
    def buildDays(self):
        result = []
        for day in range (1, 32):
            result.append(str('%d' % (day)))
        return result

    security.declarePublic('buildMonths')
    def buildMonths(self):
        result = []
        for month in range (1, 13):
            result.append(str('%d' % (month)))
        return result
    
    security.declarePublic('buildYears')
    def buildYears(self):
        result = []
        start = (DateTime().year() - 2)
        end = (DateTime().year() + 5)
        for year in range (start, end):
            result.append(str(year))
        return result

    security.declarePublic('getStartTimeString')
    def getStartTimeString( self ):
        """
            Return our start time as a string.
        """
        return self.effective().AMPMMinutes() 

    security.declarePublic('getStopTimeString')
    def getStopTimeString( self ):
        """
            Return our stop time as a string.
        """
        return self.expires().AMPMMinutes() 

# Intialize the Resume class, setting up security.
InitializeClass(Resume)
